@@ -30,7 +30,7 @@ use Module::Pluggable::Ordered
     except      => qr/^MojoMojo::Plugin::/,
     require     => 1;
 
-our $VERSION = '1.00';
+our $VERSION = '1.02';
 use 5.008004;
 
 MojoMojo->config->{authentication}{dbic} = {
@@ -98,6 +98,14 @@ if ($@ ) {
 MojoMojo->model('DBIC')->schema->attachment_dir( MojoMojo->config->{attachment_dir}
         || MojoMojo->path_to('uploads') . '' );
 
+=head1 METHODS
+
+=head2 prepare
+
+Accomdate a forcing of SSL if needed in a reverse proxing setup
+
+=cut
+
 sub prepare {
     my $self = shift->next::method(@_);
     if ( $self->config->{force_ssl} ) {
@@ -143,6 +151,10 @@ http://mojomojo.org or read the installation instructions in
 L<MojoMojo::Installation> to try it out yourself.
 
 
+=head2 ajax
+
+ajax request header
+
 =cut
 
 sub ajax {
@@ -278,6 +290,12 @@ sub fixw {
     return $w;
 }
 
+=head2 prepare_action
+
+Provide No DB message when one needs to spawn the db (script/mojomojo_spawn.pl)
+
+=cut
+
 sub prepare_action {
     my $c = shift;
 
@@ -371,9 +389,18 @@ sub uri_for {
     return $res;
 }
 
+=head2 uri_for_static
+
+static has been remapped to .static
+
+=cut
+
 sub uri_for_static {
     my ( $self, $asset ) = @_;
-    return ( $self->config->{static_path} || '/.static/' ) . $asset;
+     return 
+        ( defined($self->config->{static_path} ) 
+     ?  $self->config->{static_path} . $asset 
+     :  $self->uri_for('/.static', $asset) );
 }
 
 sub _cleanup_path {
@@ -414,35 +441,39 @@ sub _expand_path_elements {
     return @paths_to_check;
 }
 
-#  Permissions are checked prior to most actions, including view if that is
-#  turned on in the configuration. The permission system works as follows.
-#  1. There is a base set of rules which may be defined in the application
-#     config, these are:
-#          $c->config->{permissions}{view_allowed} = 1; # or 0
-#     similar entries exist for delete, edit, create and attachment.
-#     if these config variables are not defined, default is to allow
-#     anyone to do anything.
-#
-#   2. Global rules that apply to everyone may be specified by creating a
-#      record with a role-id of 0.
-#
-#   3. Rules are defined using a combination of path, and role and may be
-#      applied to subpages or not.
-#
-#   4. All rules matching a given user's roles and the current path are used to
-#      determine the final yes/no on each permission. Rules are evaluated from
-#      least-specific path to most specific. This means that when checking
-#      permissions on /foo/bar/baz, permission rules set for /foo will be
-#      overridden by rules set on /foo/bar when editing /foo/bar/baz. When two
-#      rules (from different roles) are found for the same path prefix, explicit
-#      allows override denys. Null entries for a given permission are always
-#      ignored and do not effect the permissions defined at earlier level. This
-#      allows you to change certain permissions (such as create) only while not
-#      affecting previously determined permissions for the other actions. Finally -
-#      apply_to_subpages yes/no is exclusive. Meaning that a rule for /foo with
-#      apply_to_subpages set to yes will apply to /foo/bar but not to /foo alone.
-#      The endpoint in the path is always checked for a rule explicitly for that
-#      page - meaning apply_to_subpages = no.
+=head2 get_permissions_data
+
+  Permissions are checked prior to most actions, including view if that is
+  turned on in the configuration. The permission system works as follows.
+  1. There is a base set of rules which may be defined in the application
+     config, these are:
+          $c->config->{permissions}{view_allowed} = 1; # or 0
+     similar entries exist for delete, edit, create and attachment.
+     if these config variables are not defined, default is to allow
+     anyone to do anything.
+
+   2. Global rules that apply to everyone may be specified by creating a
+      record with a role-id of 0.
+
+   3. Rules are defined using a combination of path, and role and may be
+      applied to subpages or not.
+
+   4. All rules matching a given user's roles and the current path are used to
+      determine the final yes/no on each permission. Rules are evaluated from
+      least-specific path to most specific. This means that when checking
+      permissions on /foo/bar/baz, permission rules set for /foo will be
+      overridden by rules set on /foo/bar when editing /foo/bar/baz. When two
+      rules (from different roles) are found for the same path prefix, explicit
+      allows override denys. Null entries for a given permission are always
+      ignored and do not effect the permissions defined at earlier level. This
+      allows you to change certain permissions (such as create) only while not
+      affecting previously determined permissions for the other actions. Finally -
+      apply_to_subpages yes/no is exclusive. Meaning that a rule for /foo with
+      apply_to_subpages set to yes will apply to /foo/bar but not to /foo alone.
+      The endpoint in the path is always checked for a rule explicitly for that
+      page - meaning apply_to_subpages = no.
+      
+=cut
 
 sub get_permissions_data {
     my ( $c, $current_path, $paths_to_check, $role_ids ) = @_;
@@ -536,6 +567,12 @@ sub get_permissions_data {
     return $permdata;
 }
 
+=head2 user_role_ids
+
+Get the list of role ids for a user
+
+=cut
+
 sub user_role_ids {
     my ( $c, $user ) = @_;
 
@@ -549,6 +586,12 @@ sub user_role_ids {
     return @role_ids;
 }
 
+=head2 check_permissions
+
+Check user permissions for a path
+
+=cut
+
 sub check_permissions {
     my ( $c, $path, $user ) = @_;
 
@@ -657,6 +700,12 @@ sub check_permissions {
     return \%perms;
 }
 
+=head2 check_view_permission
+
+Check if a user can view a path
+
+=cut
+
 sub check_view_permission {
     my $c = shift;
 
@@ -684,6 +733,7 @@ my $search_setup_failed = 0;
 
 MojoMojo->config->{index_dir} ||= MojoMojo->path_to('index');
 MojoMojo->config->{attachment_dir} ||= MojoMojo->path_to('uploads');
+MojoMojo->config->{root} ||= MojoMojo->path_to('root');
 unless (-e MojoMojo->config->{index_dir}) {
     if (not mkdir MojoMojo->config->{index_dir}) {
        warn 'Could not make index directory <'.MojoMojo->config->{index_dir}.'> - FIX IT OR SEARCH WILL NOT WORK!';
